%Description: MATLAB portion of the analysis carried out
%   from the data derived from:
%
%   Genomic analysis of LexA binding reveals the permissive nature of the
%   Escherichia coli genome and identifies unconventional target sites
%   Wade,J Reppas, N, Church, G, Struhl,K. Genes and Development
%   19:2619-2630
%
%   Analysis takes the following shape:
%
%   (1) Create .fasta files for the ChiP-Chip dataset
%       A -> Authentic sites
%       B -> type I and type II conserved, in place of type III sites,
%            randomly selected 1000-mers from around the genome
%
%   (2) MotifCatcher
%
%       4 motif-finding strategies:
%
%       (1) Standard - single ZOOPS model on the whole data set, all at
%           once
%
%       [MotifCatcher Series 1]
%       (2) Build different motifs from random subsets of the whole data
%           set, best motifs, tree comparison
%
%       [MotifCatcher Series 2]
%       (3) Build different motifs from a single MAST-through-filtered
%           subset of the whole data set, tree comparison
%
%       [MotifCatcher Series 3]
%       (4) Iterative MEME/MAST -> convergence, motif tree 
%           (full-scale MotifCatcher)
%
%       Evaluate on two varieties of data set:
%
%       (A) (30) type I, type II confirmed sites + (19) type III sites 
%       (B) (30) type I, type II confirmed sites + (19) Random sites
%
%       Series 1: 500 runs, seed size = 20
%       Series 2: 200 runs, seed size = 5
%       Series 3: 50 runs, seed size = 5
%
%   (3) MotifCatcher post-processing: 
%       (for each MotifCatcher Series data set)
%       [1] Determine Motif Sites
%       [2] Compare with TSS
%       [3] Graphically visualize results
%
%   (4) 19 Novel sites analysis
%       [1] Import type III inclusion in top family from each MC search
%       [2] Generate type III sequence map
%       [3] Compare
%
%   (5) Extra analyses (kept for reference)
%
%
%   Comments: This file is a bit large and messy, and contains many
%   analyses that either changed substantially from this implementation to
%   the MotifCatcher methods paper, or were ultimately not carried out.
%   This script coordinatesly quite heavily with loading output 
%   'DataSetProfile' structures produced by MATLAB. The notation here may
%   be a bit out of date with the latest software version, however the
%   process is essentially the same.
%
%   This file features a long look at comparisons with a list of TSS sites,
%   (TSS = Transcription Start Site) these analyses were never quite 
%   convincing enough to include in the manuscript (some patterns seem to
%   be there, althought a bit noisy.

%% (1) Create .fasta files

% ----------------------------------------------------------------------- %
% -- (30) type I, type II confirmed sites + (19) type III sites --------- %
% ----------------------------------------------------------------------- %

%   Import the sites.
%   Note that the original table has been modified slightly for easy import
%   in a plain text file.

fid = fopen('/Users/phillipseitzer/Documents/EColiLexA/ChiPChiP_table');
extraction = textscan(fid,'%s\t%s\t%s\t%s\t%s\t%s\n');
fclose(fid);

%   translate extract coordinates to doubles, write to a single site list.

SiteList = cell(2,length(extraction{1,2}));
for i = 1:length(extraction{1,2})
    SiteList{1,i} = extraction{1,2}{i,1};
    SiteList{2,i} = extraction{1,3}{i,1};
end

%parameters
Urange = 500;
Drange = 500;
GenomeFile = '/Users/phillipseitzer/Documents/EColiLexA/EColi_MG1655.fasta';
outputfilename = '/Users/phillipseitzer/Documents/EcoliLexA/LexA_R500_tagged.fasta';

%build .fasta
List2RegRegions(SiteList,Urange,Drange,GenomeFile,outputfilename);

% ----------------------------------------------------------------------- %
% -- (30) type I, type II confirmed sites + (19) Rand sites ------------- %
% ----------------------------------------------------------------------- %

%build random 1000-mers for the 19 type III sites.
%import
[header sequence] = fastaread(...
    '/Users/phillipseitzer/Documents/EColiLexA/EColi_MG1655.fasta');

%randomize
RP = randperm(length(sequence));

%form 19 new alternative sites, at random places around the genome, to take
%the place of the type III sites.
AlternativeSites = [];
Counter = 0;

while length(AlternativeSites) < 1000
    Counter = Counter + 1;
    GoodForaGo = 1;
    
    %check the list of sites in the original set.
    for j = 1:length(SiteList(1,:));
        if abs(SiteList{1,j}-RP(Counter)) <= 500
           GoodForaGo = 0; 
           disp(['Sitelist DQ ' num2str(j) ' : ' num2str(RP(Counter))]);
        end
    end
    
    %also check the existing Alternative Sites list.
    if ~isempty(AlternativeSites)
        for j = 1:length(AlternativeSites)
            if abs(AlternativeSites(j)- RP(Counter)) <= 500
                GoodForaGo = 0;
                disp(['AltList DQ ' num2str(j) ' : ' num2str(RP(Counter))]);
            end
        end
    end
    
    %if the site does not overlap with any other alternative sites, or
    %sites on the original site list, it is deemed a suitable random site
    %to check for motifs.
    if GoodForaGo == 1
        AlternativeSites = [AlternativeSites RP(Counter)];
        disp(['Match at ' num2str(Counter) ' : ' num2str(RP(Counter))]);
    end
end

%Now, we join the Alternative Site List with the original I and II site
%list.
SiteList2 = SiteList;
AltCounter = 0;
for i = 1:length(SiteList2(2,:))
   if ~isempty(strmatch('III',SiteList2{2,i}))
       AltCounter = AltCounter + 1;
       SiteList2{1,i} = num2str(AlternativeSites(AltCounter));
       SiteList2{2,i} = 'Rand';
   end
end

%This completes the acceptable list.  all variables are passed as usual.

%parameters
Urange = 500;
Drange = 500;
GenomeFile = '/Users/phillipseitzer/Documents/EColiLexA/EColi_MG1655.fasta';
outputfilename = '/Users/phillipseitzer/Documents/EcoliLexA/LexA_R500_random.fasta';

List2RegRegions(SiteList2,Urange,Drange,GenomeFile,outputfilename);

%% (1b) Generating new TSS Sites

%initialize
AlternativeSites_with_TSS = zeros(1000,2);

%load command
%load('MotifCatcher_Methods_Analyses/Palsson_TSS_sites.mat');

TotalTSS = 0;
for i = 1:1000
   
   %write value  
   AlternativeSites_with_TSS(i,1) = AlternativeSites(i);
   
   %determine if nearby TSS - if so, write '1', if not, '0'.
   for j = 1:length(Palsson_TSS(:,1))
       if abs(AlternativeSites(i)-Palsson_TSS{j,3}) <= 500
           AlternativeSites_with_TSS(i,2) = 1;
       end
   end
   
   %print message
   disp(['Random Site ' num2str(i) ' completed.']);
end

%build a matrix of 20 possible random datasets, each containing between 0
%to 19 TSS sites, and the balance non-TSS sites.
RandSets = cell(20,20);

%randomize drawing
X = randperm(length(AlternativeSites_with_TSS(:,1)));
RPCounter_TSS = 0;
RPCounter_noTSS = 0;
   
%from this list, pick up 19 new 1000-mers with a TSS nearby and 19 without
for i = 1:20
   
   %initialize RandSets
   RandSets{1,i} = [num2str(i-1) '_TSS'];
   
   %initialize TSS Sites
   TSSSites = 0;
   
   while (TSSSites < i-1)
       
        %increment RPCounter
        RPCounter_TSS = RPCounter_TSS + 1;
       
        if AlternativeSites_with_TSS(X(RPCounter_TSS),2) == 1
           TSSSites = TSSSites + 1;
           RandSets{TSSSites+1,i} = AlternativeSites_with_TSS(X(RPCounter_TSS),1);
        end
       
   end
   
   %initialize non-TSS Sites
   nonTSSSites = 0;
   
   while (nonTSSSites < 19 - TSSSites)
       
       %increment RPCounter
       RPCounter_noTSS = RPCounter_noTSS + 1;
       
       if AlternativeSites_with_TSS(X(RPCounter_noTSS),2) == 0
          nonTSSSites = nonTSSSites + 1;
          RandSets{nonTSSSites+TSSSites+1,i} = AlternativeSites_with_TSS(X(RPCounter_noTSS),1);
       end
   end
   
end

%test: do any of these sites violate the +/- 500 bp overlapping rule?
for i = 2:20
   for j = 1:20
       CompareTo = RandSets{i,j};
       for k = 2:20
          for l = 1:20;
              %compare
             if i ~= k && j ~=l
                if isequal(RandSets{i,j},RandSets{k,l})
                    disp('violation')
                end
             end
          end
       end
   end
end
%ans: no


%save useful variables
save('MotifCatcher_Methods_Analyses/TSS_Random.mat','RandSets','AlternativeSites_with_TSS');

%build data sets - note global parameters

%parameters
Urange = 500;
Drange = 500;
GenomeFile = '/Users/phillipseitzer/Documents/MotifCatcher_Methods/EColiLexA/Other/EColi_MG1655.fasta';
FileDir = '/Users/phillipseitzer/Documents/MotifCatcher_Methods/EColiLexA/Datasets/LexA_RandomTSS';

for i = 1:20

%Create an alternative sites list by joining a rand set column with the 
%original I and II site

SiteList2 = SiteList;
AltCounter = 0;
for j = 1:length(SiteList2(2,:))
   if ~isempty(strmatch('III',SiteList2{2,j}))
       AltCounter = AltCounter + 1;
       SiteList2{1,j} = num2str(RandSets{AltCounter+1,i});
       SiteList2{2,j} = 'Rand';
   end
end

%This completes the acceptable list.  now we create the data set.
outputfilename = strcat(FileDir,'/LexA_Random_',RandSets{1,i},'.fasta');

%extract actual regions
List2RegRegions(SiteList2,Urange,Drange,GenomeFile,outputfilename);

end
%% (2) MotifCatcher Analysis
%
% All: -500:+500 from sites (1001-mers), No revcomp, 6 to 30 nt
%   ALLR, SWA, ClusteringThreshold = 1;
%

% ----------------------------------------------------------------------- %
% ----- Series 1: Purely random subsets, 500 runs ----------------------- %
% ----------------------------------------------------------------------- %

%A:
load('/Users/phillipseitzer/Documents/MotifCatcher_Methods/EColiLexA/MotifCatcher/noMAST/TypeIII/CESP0.50/DataSetProfile.mat');

%B:
load('/Users/phillipseitzer/Documents/MotifCatcher_Methods/EColiLexA/MotifCatcher/noMAST/Rand/CESP0.70/DataSetProfile.mat');

sum = 0;
for i = 1:length(DataSetProfile.AllMotifsAndLocations)
   sum = sum + length(DataSetProfile.AllMotifsAndLocations{1,i}(1,:)) - 1; 
end


%NOTE: for clusters in Sens/Spec figure, use 'MotifTree100'

%RAND sum = 
%type III sum = 
  
% A: (30) type I and II + (19) type III: 
%           361 of 500 ES significant
%           66/361 -> 18.28% of valid ES related to a significant result
%           66/500 -> 13.2% of all trials lead to a significant result
%
% B: (30) type I and II + (19) random:
%           314 of 500 ES significant
%           28/314 -> 8.92% of valid ES related to a significant result
%           28/500 -> 5.6% of all trials lead to a significant result
%
% Using a type III site in place of a random site results in convergence 3
% times more often
%

% ----------------------------------------------------------------------- %
% ----- Series 2: Single MAST-through, 200 runs ------------------------- %
% ----------------------------------------------------------------------- %

%A:
load('/Users/phillipseitzer/Documents/MotifCatcher_Runs/Results/EColiLexA/NonConv/R500tmany/CESP0.50/DataSetProfile.mat');

%B:
load('/Users/phillipseitzer/Documents/MotifCatcher_Runs/Results/EColiLexA/NonConv/Rand/CESP0.50/DataSetProfile.mat');

sum = 0;
for i = 1:length(DataSetProfile.AllMotifsAndLocations)
   sum = sum + length(DataSetProfile.AllMotifsAndLocations{1,i}(1,:)) - 1; 
end

%RAND sum = 89
%type III sum = 116
   
% A: (30) type I and II + (19) type III: 
%           116 of 200 ES significant
%           63/116 -> 54% of valid ES related to a significant result
%           63/200 -> 32% of all trials lead to a signifcant result
%
% B: (30) type I and II + (19) random:
%           89 of 200 ES significant
%           22/89 -> 25% of valid ES related to a significant result
%           22/200 -> 11% of all trials lead to a significant result
%
% Using a type III site in place of a random site results in convergence 3
% times more often
%

% ----------------------------------------------------------------------- %
% ----- Series 3: Full Convergence, 50 runs ----------------------------- %
% ----------------------------------------------------------------------- %

%A:
load('/Users/phillipseitzer/Documents/MotifCatcher_Methods/EColiLexA/MotifCatcher/PSI-MEME/TypeIII/CESP0.80/DataSetProfile.mat');

%B:
load('/Users/phillipseitzer/Documents/MotifCatcher_Methods/EColiLexA/MotifCatcher/PSI-MEME/Rand/CESP0.70/DataSetProfile.mat');

sum = 0;
for i = 1:length(DataSetProfile.AllMotifsAndLocations)
   sum = sum + length(DataSetProfile.AllMotifsAndLocations{1,i}(1,:)) - 1; 
end

%type III sum = 
%RAND sum =   

% A: (30) type I and II + (19) type III: 
%           50 of 50 ES significant
%           48/50 -> 96% of valid ES related to a significant result
%           50/50 -> 100% of all trials lead to a signifcant result
%
% B: (30) type I and II + (19) random:
%           48 of 50 ES significant
%           23/48 -> 47.92% of valid ES related to a significant result
%           23/50 -> 46% of all trials lead to a significant result
%
% Using a type III site in place of a random site results in convergence 3
% times more often

% ======================================================================= %
%% (3) MotifCatcher post-processing

% ----------------------------------------------------------------------- %
% ----- Series 1: Purely random subsets, 500 runs ----------------------- %
% ----------------------------------------------------------------------- %

% ==[1]== Determine Motif Sites ========================================= %
% ==[2]== Compare with TSS ============================================== %
% ==[3]== Graphically visualize results ================================= %

% ----------------------------------------------------------------------- %
% ----- Series 2: Single MAST-through, 200 runs ------------------------- %
% ----------------------------------------------------------------------- %

% ==[1]== Determine Motif Sites ========================================= %

%A: (30) type I and II + (19) type III: 
load('/Users/phillipseitzer/Documents/MotifCatcher_Methods/EColiLexA/MotifCatcher/PSI-MEME/TypeIII/CESP0.875/DataSetProfile.mat');

%input parameters:
   MembershipMatrix = DataSetProfile.AllMotifsAndLocations{1,1};
   TolerancetoMiddle = 15;
   RejectionThreshold = 0.20;

Groups = DetermineMSites(...
    MembershipMatrix,TolerancetoMiddle,RejectionThreshold);
   
%B: (30) type I and II + (19) random::
load('/Users/phillipseitzer/Documents/MotifCatcher_Runs/Results/EColiLexA/Rand/CESP0.50/DataSetProfile.mat');

%input parameters:
   MembershipMatrixR = DataSetProfile.AllMotifsAndLocations{1,1};
   TolerancetoMiddle = 15;
   RejectionThreshold = 0.20;

GroupsR = DetermineMSites(...
    MembershipMatrixR,TolerancetoMiddle,RejectionThreshold);

save('DetermineSitesAnalysis.mat','Groups',...
    'MembershipMatrix','RejectionThreshold','TolerancetoMiddle',...
    'MembershipMatrixR','GroupsR');

% ==[2]== Compare with TSS ============================================== %

%compute results
TSSResults = EColiLexA_TSS(Groups);
TSSResultsR = EColiLexA_TSS(GroupsR);

save('TSSResults.mat','TSSResults','TSSResultsR');

% ==[3]== Graphically visualize results ================================= %

%A: (30) type I and II + (19) type III:
file = ...
    '/Users/phillipseitzer/Documents/EColiLexA/LexA_R500_tagged.fasta';

MM = MembershipMatrix(3:length(MembershipMatrix(:,1)),:);
MM1 = [];
MM2 = [];
MM3 = [];
for i = 1:length(MM(:,1))
   if strfind(MM{i,1},'[I]')
       MM1 = vertcat(MM1,MM(i,:));      
   elseif strfind(MM{i,1},'[II]')
       MM2 = vertcat(MM2,MM(i,:));
   else
       MM3 = vertcat(MM3,MM(i,:));
   end
end

EColiLexA_MotifSites(MM1,file,'A_typeI.txt')
EColiLexA_MotifSites(MM2,file,'A_typeII.txt')
EColiLexA_MotifSites(MM3,file,'A_typeIII.txt')

 
%B: (30) type I and II + (19) Rand:
file = ...
    '/Users/phillipseitzer/Documents/EColiLexA/LexA_R500_random.fasta';

MM = MembershipMatrixR(3:length(MembershipMatrixR(:,1)),:);
MM1 = [];
MM2 = [];
MM3 = [];
for i = 1:length(MM(:,1))
   if strfind(MM{i,1},'[I]')
       MM1 = vertcat(MM1,MM(i,:));      
   elseif strfind(MM{i,1},'[II]')
       MM2 = vertcat(MM2,MM(i,:));
   else
       MM3 = vertcat(MM3,MM(i,:));
   end
end

EColiLexA_MotifSites(MM1,file,'B_typeI.txt')
EColiLexA_MotifSites(MM2,file,'B_typeII.txt')
EColiLexA_MotifSites(MM3,file,'B_Rand.txt')

% ----------------------------------------------------------------------- %
% ----- Series 3: Full Convergence, 50 runs ----------------------------- %
% ----------------------------------------------------------------------- %

% ==[1]== Determine Motif Sites ========================================= %
% ==[2]== Compare with TSS ============================================== %
% ==[3]== Graphically visualize results ================================= %


%Observations:
%
%
%   A_typeI:
%      25/25: The same stretch of sequence is chosen to build the motif.
%
%   A_typeII:
%       4/5: The same stretch of sequence is chosen to build the motif.
%       1/5: 62% in one place, 38% in another place, 121 nt away
%   
%   A_typeIII:
%       7/19: one group
%       9/19: two groups
%       3/19: three groups
%
%   B_Rand:
%       6/19: one group
%       8/19: two groups
%       4/19: three groups
%       1/19: four groups
%
%   A and B type I and type II results look exactly the same.
%
%   A_typeIII vs. Rand
%
%   
% Question - how would type III compare to random intergenic regions?
%
% On the other hand, the chip-chip dataset is annotation-blind
%
%
 

%some additional analysis
Counter = 0;
for i = 1:length(GroupsR)
   if ~isempty(strfind(GroupsR{i,1},'[Rand]')) && GroupsR{i,3}==5
       Counter = Counter + 1;
       disp([GroupsR{i,1} ' had 1 group'])
   end
end


% --2119783:2120783--[Rand] had 1 group
% --502569:503569--[Rand] had 1 group + nearby TSSs
% --2262841:2263841--[Rand] had 1 group + nearby TSSs
% --2250139:2251139--[Rand] had 1 group
% --1471873:1472873--[Rand] had 1 group + nearby TSSs
% --3393153:3394153--[Rand] had 1 group


%thoughts

%There are several cases to consider in evaluating chip-chip sites versus
%motif localization relative to TSS Sites:
%
% cc = chip-chip
%
% (1) The cc site and all discovered motifs do not find any TSS sites.
% (2) The cc site does not find a TSS site, but a discovered motif does.
% (3) Both the cc site and the discovered motifs find 1 or more TSS.
%       (a) A motif site is closer to a TSS, compared to cc.
%           Consider: relative frequency
%       (b) the motif site and cc site are comparatively far away from TSS
%       (c) the motif site is worse than the cc site for TSS.
%
%  Type (1) suggests that the chip-chip results are in error; the whole
%  data point is irrelevant.  Alternatively, a TSS result is missing from
%  the list that would apply to this data point.
%
%  Type (2) potentially serves as a line of evidence in favor of the motif,
%  however, the TSS is likely to be quite far away from the motif.
%
%  Type (3)-a are the best cases, especially when a motif shows a
%  substantial improvement, and high frequency
%
%  Type (3)-b might not necessarily be bad, especially if the cc is quite
%  close to a TSS to start.
%
%  Type (3)-c could be bad, especially instances where the cc is close and
%  a motif instance is far away.

% ======================================================================= %

%(4) collect E-values from top-scoring values

EVals_noMAST = TopFamilyEVals('/Users/phillipseitzer/Documents/MotifCatcher_Methods/EColiLexA/MotifCatcher/noMAST/Rand');
EVals_MAST = TopFamilyEVals('/Users/phillipseitzer/Documents/MotifCatcher_Methods/EColiLexA/MotifCatcher/MAST-once/Rand');
EVals_PSI = TopFamilyEVals('/Users/phillipseitzer/Documents/MotifCatcher_Methods/EColiLexA/MotifCatcher/PSI-MEME/Rand');

EVals = struct();

EVals.EVals_noMAST = EVals_noMAST;
EVals.EVals_MAST = EVals_MAST;
EVals.EVals_PSI = EVals_PSI;

save('EVals.mat','EVals');

%% (4) Novel sites


%(A) Iterative MEME/MAST case
%load data
load('/Users/phillipseitzer/Documents/MotifCatcher_Methods/EColiLexA/MotifCatcher/PSI-MEME/TypeIII/CESP0.875/DataSetProfile.mat');

%define variables
Family = DataSetProfile.AllMotifsAndLocations{1,1};
SeqFile = DataSetProfile.SeqFile;
outputfilename = '/Users/phillipseitzer/Documents/MotifCatcher_Methods/EColiLexA/MotifCatcher/PSI-MEME/TypeIII/TypeIIISites.txt';
TolerancetoMiddle = 15;
RejectionThreshold = .10;

%run all tests
%text output
MotifFamily2txt(Family,SeqFile,outputfilename,'[III]');

%sort into groups
Groups_typeIII = Family2MotifGroups(Family,TolerancetoMiddle,RejectionThreshold,'[III]');

%Pull out subsequences
GroupswSubseqs_typeIII = MotifGroups2Subseqs(Groups_typeIII,SeqFile);

%Compare with canonical LexA site, local alignment
for i = 1:length(GroupswSubseqs_typeIII)
   if ~isempty(GroupswSubseqs_typeIII{i,2})
      [Score Alignment] = swalign('CTGXXXXXXXXXXCAG',GroupswSubseqs_typeIII{i,2});
      GroupswSubseqs_typeIII{i,4} = Score;
      GroupswSubseqs_typeIII{i,5} = Alignment;
   end
end

%next: add by-hand annotations

%(B) Iterative MEME/MAST, random set:
%load data
load /Users/phillipseitzer/Documents/MotifCatcher_Methods/EColiLexA/MotifCatcher/PSI-MEME/Rand/CESP0.80/DataSetProfile.mat

%define variables
Family = DataSetProfile.AllMotifsAndLocations{1,1};
SeqFile = DataSetProfile.SeqFile;
outputfilename = '/Users/phillipseitzer/Documents/MotifCatcher_Methods/EColiLexA/MotifCatcher/PSI-MEME/Rand/RandSites.txt';
TolerancetoMiddle = 15;
RejectionThreshold = .10;

%run all tests
%text output
MotifFamily2txt(Family,SeqFile,outputfilename,'Rand');

%sort into groups
Groups_Rand = Family2MotifGroups(Family,TolerancetoMiddle,RejectionThreshold,'Rand');

%Pull out subsequences
GroupswSubseqs_Rand = MotifGroups2Subseqs(Groups_Rand,SeqFile);

%Compare with canonical LexA site, local alignment
for i = 1:length(GroupswSubseqs_Rand)
   if ~isempty(GroupswSubseqs_Rand{i,2})
      [Score Alignment] = swalign('CTGXXXXXXXXXXCAG',GroupswSubseqs_Rand{i,2});
      GroupswSubseqs_Rand{i,4} = Score;
      GroupswSubseqs_Rand{i,5} = Alignment;
   end
end

ScoreCounter = 0;
ScoreSum = 0;
for i = 1:length(GroupswSubseqs_typeIII)
   if ~isempty(GroupswSubseqs_typeIII{i,3}) && GroupswSubseqs_typeIII{i,3} > 0.10
       ScoreCounter = ScoreCounter + 1;
       ScoreSum = ScoreSum + GroupswSubseqs_typeIII{i,4};
   end
end

ScoreAvg= ScoreSum/ScoreCounter;

ScoreCounter = 0;
ScoreSum = 0;
for i = 1:length(GroupswSubseqs_Rand)
   if ~isempty(GroupswSubseqs_Rand{i,3}) && GroupswSubseqs_Rand{i,3} > 0.10
       ScoreCounter = ScoreCounter + 1;
       ScoreSum = ScoreSum + GroupswSubseqs_Rand{i,4};
   end
end

ScoreAvg_rand= ScoreSum/ScoreCounter;


GroupswSubseqs = GroupswSubseqs_Rand;
%GroupswSubseqs = GroupswSubseqs_typeIII;

Counter = 0;
for i = 1:length(GroupswSubseqs)
    FoundOne = false;
    if ~isempty(GroupswSubseqs{i,2})
%         %ATG-CATs only
%         X = strfind(GroupswSubseqs{i,2},'ATG');
%         Y = strfind(GroupswSubseqs{i,2},'CAT');
        
        %ATG-CATs, CTG-CATs, ATG-CAGs, and CTG-CAGs
         X1 = strfind(GroupswSubseqs{i,2},'ATG');
         X2 = strfind(GroupswSubseqs{i,2},'CTG');
         
         X = [X1 X2];
         
         Y1 = strfind(GroupswSubseqs{i,2},'CAT');  
         Y2 = strfind(GroupswSubseqs{i,2},'CAG');
         
         Y = [Y1 Y2];
         
        %compare coordinates
        if ~isempty(X) && ~isempty(Y)
            for k = 1:length(X)
               for j = 1:length(Y)
                    if Y(j) - X(k) == 13
                        FoundOne = true;
                        disp(['exact match at ' num2str(i) ])
                    end
               end
            end
        end
        if FoundOne == true
           Counter = Counter + 1; 
        end
   end
end


fid = fopen('/Users/phillipseitzer/Documents/MotifCatcher_Methods/EColiLexA/Other/ChipChip_table');

extraction = textscan(fid,'%s\t%s\t%s\t%s\t%s\t%s\n');

fclose(fid);

counter = 0;
for i = 1:length(extraction{1,1})
   if strmatch(extraction{1,3}{i,1},'III','exact') 
      disp([extraction{1,4}{i,1}]) 
      counter = counter + 1;
   end
end
%% (5) Extra
% 
% %(4) old novel sites analysis
% %Analysis:
% %(0) Build sequence dataset, complete MEME run.
% %(1) Large MotifCatcher run -> candidate sets of motifs
% %(2) For each candidate motif, and motif site, find closest TSS sites
% %(3) Look over results, see if anything suggests a direct TSS binding site.
% 
% %(0)
% [header sequence] = ...
%     fastaread('/Users/phillipseitzer/Documents/MotifCatcher_Methods/EColiLexA/Datasets/LexA_500_tagged.fasta');
% 
% file = '/Users/phillipseitzer/Documents/MotifCatcher_Methods/EColiLexA/Datasets/LexA_TypeIII.fasta';
% 
% for i = 1:length(header)
%    if strfind(header{1,i},'[III]')
%       fastawrite(file,header{1,i},sequence{1,i});
%    end
% end
% 
% %(1) Large MotifCatcher run 
% %   -> candidate sets of motifs for trial are elucidated in families.
% 
% load('/Users/phillipseitzer/Documents/MotifCatcher_Methods/EColiLexA/MotifCatcher/OnlyTypeIIImany/CESP0.80/DataSetProfile.mat');
% 
% %universal parameters
% TolerancetoMiddle = 15;
% RejectionThreshold = 0.20;
% 
% %Initialize Groups and TSS Results
% T3_Groups = cell(1,length(DataSetProfile.AllMotifsAndLocations));
% T3_TSSResults = cell(1,length(DataSetProfile.AllMotifsAndLocations));
% 
% %groups, and TSS results
% for i = 1:length(T3_Groups)
%     
%    %determine groups
%    T3_Groups{1,i} = DetermineMSites(DataSetProfile.AllMotifsAndLocations{1,i},...
%        TolerancetoMiddle,RejectionThreshold);
%    
%    %map groups back to TSS list
%    A = EColiLexA_TSS(T3_Groups{1,i});
%    T3_TSSResults{1,i} = A{1,3};
%    
% end
% 
% %initialize - one extra for MEME, one extra for header
% CompStats = cell(length(DataSetProfile.AllMotifsAndLocations)+2,3);
% CompStats{1,1} = 'Number of Sites';
% CompStats{1,2} = 'TSS inclusion ratio';
% CompStats{1,3} = 'Improvement ratio';
% 
% %Comparative statistics on results
% % Of interest:
% %   'Number of Sites' : number of sites total building the PWM
% %   'TSS inclusion ratio' : number of sites that have a nearby TSS
% %   'Improvement ratio' : number of sites with a nearby TSS that offers
% %       improvement over the center of the region (more than 5 nt)
% 
% %import MEME
% 
% %first, make a membership matrix with the sites and coordinates.
% RevComp = 1;
% [SeqFileHeader SeqFileSequence] = ...
%     fastaread('/Users/phillipseitzer/Documents/MotifCatcher_Methods/EColiLexA/Datasets/LexA_TypeIII.fasta');
% InputSet = {'/Users/phillipseitzer/Documents/MotifCatcher_Methods/EColiLexA/MEME/Only_TypeIII'};
% MM = MC_MakeMembershipMatrix(InputSet,SeqFileHeader,RevComp);
% blanks = cell(2,2);
% MembershipMatrixt3MEME = vertcat(blanks,MM);
% MembershipMatrixt3MEME{2,2} = 'MEME_run';
% 
% %determine groups
% Groupst3MEME = DetermineMSites(...
%     MembershipMatrixt3MEME,TolerancetoMiddle,RejectionThreshold);
% 
% %map of TSS sites
% TSSResultst3MEME = EColiLexA_TSS(Groupst3MEME);
% 
% %determine regions defining each site
% NewRegions = [];
% for i = 2:length(TSSResultst3MEME{1,3}(:,1))
%    if ~isempty(TSSResultst3MEME{1,3}{i,1}) 
%         NewRegions = [NewRegions i];
%    end
% end
% 
% %add length of file at end
% NewRegions = [NewRegions length(TSSResultst3MEME{1,3}(:,1))];
% 
% %compute statistics for each site
% 
% NumSites = 0;
% HasTSS = false;
% TSSImprovement = false;
% 
% for i = 1:length(NewRegions)-1
%    for j = NewRegions(i)+1:NewRegions(i+1)-1
%       
%    end
%    
%    %add TSS
%    if HasTSS == true
%        
%        if TSSImprovement == true;
%            
%        end
%        
%    end
%    
% end
% 
% for i = 1:length(T3_TSSResults)
%     
%    NotEmpty = EColiLexA_Statistics(T3_TSSResults{1,i});
%    disp(['entry ' num2str(i) ': ' num2str(NotEmpty) ' of ' num2str(length(DataSetProfile.AllMotifsAndLocations{1,i})-2)]);
%    
% end