%Description: ChIP-seq derived Cse4p binding sites, processed and evaluated
%with MotifCatcher
%
% Analyses:
%
% (1) Import ChiP-seq data, Consolidate sites into a single list from 
%     3 replicates, CEN, new, and all
% (2) sequence extractions:
%       CEN regions are always tagged with a 'c_' in front
%       (a) entire range
%       edge of coverage region, or span from
%       (b) +/- 50 from center (100-mers)
%       (c) +/- 100 from center (200-mers)
%       (d) +/- 500 from center (1000-mers)
% (3) Serial addition study
%       take note of 'excess' score, and generate datasets with
%       increasingly weaker ChIP-seq determined sites.
%       Compare MEME ZOOPS v MotifCatcher, determine a 'break point' for
%       resolution
%           Comment: This could work or not work based on the existence (or
%           non-existence) of additional motifs.  Do these non-CEN sites
%           associated to other proteins, or to the raw DNA?  It seems they
%           don't really associate to raw DNA.  That being the case, there
%           would not be motif signatures; at least not with any significance
%           Alternatively: many weak motif reflect real interactions.
%
%           For these studies: use a background model built of all
%           sequences instead of the whole genome sequence.
%(4) Comparison to POLII sites
%       This study reveals the highly non-random distribution of polII
%       sites in Family 1 sites, but not Family 2 sites from the Cse4p data
%       set.
%
% COMMENTS:
%       This file has a number of analyses that were not reported in the
%       MotifCatcher methods paper - these include studies to determine the
%       number of non-canonical CEN sites that can be added to a list of
%       CEN sites at which MotifCatcher can still discover canonical CEN
%       sites (it takes about 20 seeds with 84 extra sites).  A comparison
%       of MEME to MotifCatcher is given at the end, following the
%       Comparison to PolII study.
%

%% (1) ChIP-seq import

%rep 1
fid = fopen('/Users/phillipseitzer/Documents/MotifCatcher_Methods/Yeast/RawData/Cse4p_Rep1');
extraction1 = textscan(fid,'chr%d\t%d\t%d\t%*s\t%*s\t%*s\t%d\t%*s\t%s');
fclose(fid);

%rep 2
fid = fopen('/Users/phillipseitzer/Documents/MotifCatcher_Methods/Yeast/RawData/Cse4p_Rep2');
extraction2 = textscan(fid,'chr%d\t%d\t%d\t%*s\t%*s\t%*s\t%d\t%*s\t%s');
fclose(fid);

%rep 3
fid = fopen('/Users/phillipseitzer/Documents/MotifCatcher_Methods/Yeast/RawData/Cse4p_Rep3');
extraction3 = textscan(fid,'chr%d\t%d\t%d\t%*s\t%*s\t%*s\t%d\t%*s\t%s');
fclose(fid);

%include chromosomal information
for i = 1:length(extraction1{1,5})
    extraction1{1,5}{i,1} = strcat('chr',num2str(extraction1{1,1}(i,1)),'-',char(extraction1{1,5}{i,1}));
end

for i = 1:length(extraction2{1,5})
    extraction2{1,5}{i,1} = strcat('chr',num2str(extraction2{1,1}(i,1)),'-',char(extraction2{1,5}{i,1}));
end

for i = 1:length(extraction3{1,5})
    extraction3{1,5}{i,1} = strcat('chr',num2str(extraction3{1,1}(i,1)),'-',char(extraction3{1,5}{i,1}));
end

%edits: achieve only unique regions, remove gaps in stretches of sequence
%(take away false positives)

extraction = extraction2;

for i = 1:length(extraction{1,1})
   key = extraction{1,2}(i,1);
   for j = i+1:length(extraction{1,2})
       if isequal(key,extraction{1,2}(j,1))
            disp(['coordinates ' num2str(i) ' and ' num2str(j) ': ' key])
       end
   end
end

% Consolidate results into a single list
%   ChIPSeqRegions:
%       Chromosome      Start       Stop    ORF     relative excess    Peak center     

%initialize
ChIPSeqRegions = cell(98,6);
for i = 1:5
    for j = 1:length(ChIPSeqRegions)
        if i == 4
           ChIPSeqRegions{j,i} = double(extraction1{1,i}(j,1))/2888; 
        else
            ChIPSeqRegions{j,i} = extraction1{1,i}(j,1);
        end
    end
end

%method 1: region is min(all 3 reps) --> max(all 3 reps)
for z = 1:2
    
    if z == 1
        extraction = extraction2;
    else
        extraction = extraction3;
    end
    
    Counter = 0;
    NewRegions = [];

    FoundORFCounter = 0;
    
    %compare each replicate to the master list.
    for i = 1:length(extraction{1,5}(:,1))

        %find search key
        ORF = extraction{1,5}{i,1};

        %set search key to 'unfound'
        FoundORF = 0;

        %search through existing ChIPSeqregions to find the ORF.
        for j = 1:length(ChIPSeqRegions(:,5))
            
            %find ORF: adjust coordinates
            if strmatch(ORF,ChIPSeqRegions{j,5},'exact')

                FoundORF = 1;
                FoundORFCounter = FoundORFCounter + 1;
                
                %adjust start coordinate to earliest
                if extraction{1,2}(i,1) < ChIPSeqRegions{j,2}
                    ChIPSeqRegions{j,2} = extraction{1,2}(i,1);
                end

                %adjust end coordinate to latest
                if extraction{1,3}(i,1) > ChIPSeqRegions{j,3}
                    ChIPSeqRegions{j,3} = extraction{1,3}(i,1);
                end
                
                %compute new excess score
                if z == 1
                    ChIPSeqRegions{j,4} = ...
                        0.5*(ChIPSeqRegions{j,4} + ...
                        double(extraction{1,4}(i,1))/1297);
                else
                    ChIPSeqRegions{j,4} = ...
                        (1/3)*(2*ChIPSeqRegions{j,4} + ...
                        double(extraction{1,4}(i,1))/4561);
                end
                
            end
        end   

        %fail to find ORF in the existing set: add coordinate
        if FoundORF == 0
            Counter = Counter + 1;

                for k = 1:6
                    if k ~= 4 && k ~= 6
                        NewRegions{Counter,k} = extraction{1,k}(i,1);
                    elseif k == 4
                        if z == 1
                            NewRegions{Counter,k} = ...
                                double(extraction{1,k}(i,1))/1297;
                        else
                            NewRegions{Counter,k} = ...
                                double(extraction{1,k}(i,1))/4561;
                        end
                    else
                        NewRegions{Counter,k} = [];
                    end
                end
        end
    end

    %add new regions.
    ChIPSeqRegions = vertcat(ChIPSeqRegions,NewRegions);
end

%compute peak centers
for i = 1:length(ChIPSeqRegions(:,1))
   ChIPSeqRegions{i,6} = round(mean([ChIPSeqRegions{i,2} ChIPSeqRegions{i,3}]));  
end

%order the list appropriately.
ChIPSeqRegions = flipud(sortrows(ChIPSeqRegions,4));

%Final Check: make sure no overlaps!
for i = 1:length(ChIPSeqRegions(:,1))
   for j = i:length(ChIPSeqRegions(:,1))
       if i ~= j
            
           %search for overlaps: compare every element to every later
           %element.
           
           %default: no overlap           
           IsOverlapping = false;
           
           %require chromosome match for further analyses
           if ChIPSeqRegions{i,1} == ChIPSeqRegions{j,1}
            
               %i may not start inside j.
               if ChIPSeqRegions{i,2} > ChIPSeqRegions{j,2} &&...
                       ChIPSeqRegions{i,2} < ChIPSeqRegions{j,3}
                  IsOverlapping = true; 
               end
               
               %i may not stop inside j.
               if ChIPSeqRegions{i,3} > ChIPSeqRegions{j,2} && ...
                       ChIPSeqRegions{i,3} < ChIPSeqRegions{j,3}
                   IsOverlapping = true;
               end
           
           end
           
           if IsOverlapping == true
              disp(['Overlap Found: ' num2str(i) ' and ' num2str(j)]);
              disp([ChIPSeqRegions{i,5} ChIPSeqRegions(i,2:3)]);
              disp([ChIPSeqRegions{j,5} ChIPSeqRegions(j,2:3)]);
           end
       end
   end
end

% Build SiteLists

% build SiteList variable
SiteList = cell(length(ChIPSeqRegions(:,1)),5);
for i = 1:length(ChIPSeqRegions(:,1))
    
%col 1: title of header
SiteList{i,1} = strcat('chr',num2str(ChIPSeqRegions{i,1}));

%col 2: peak center
SiteList{i,2} = ChIPSeqRegions{i,6};

%col 3: min peak coverage
SiteList{i,3} = ChIPSeqRegions{i,2};

%col 4: max peak coverage
SiteList{i,4} = ChIPSeqRegions{i,3};

%col 5: name
SiteList{i,5} = ChIPSeqRegions{i,5};
end

%various extractions
SiteListAll = SiteList; %all sites
SiteListCEN = vertcat(SiteList(1:9,:),SiteList(11:16,:),SiteList(18,:)); %CEN sites
SiteListNew = vertcat(SiteList(10,:),SiteList(17,:),SiteList(19:length(ChIPSeqRegions(:,1)),:)); %non-CEN sites

%note that the site lists are ordered by decreasing ChIP-seq excess score
% (ranked from experimental data)

save('MotifCatcher_Methods_Analyses/Yeast_Cse4p.mat','SiteListAll','SiteListCEN','SiteListNew','ChIPSeqRegions');

%% (2) Sequence Datasets Creation
%(1) - All, CEN, and New

GenomeFile = '/Users/phillipseitzer/Documents/MotifCatcher_Methods/Yeast/RawData/S288c/S288c_whole_genome.fasta';
Dataset_root = '/Users/phillipseitzer/Documents/MotifCatcher_Methods/Yeast/Datasets';

Datasets = {'All','CEN','NEW'};
Ranges = [50,100,500,1e10];

for i = 1:length(Datasets)
   for j = 1:length(Ranges) 
        
        %select correct sitelist
        if i == 1
            SiteList = SiteListAll;
        elseif i == 2
            SiteList = SiteListCEN;
        else
            SiteList = SiteListNew;
        end
        
        %create outputfilename
        if j ~= 4
            outputfilename = strcat(Dataset_root,'/',Datasets{1,i},'/Range',num2str(Ranges(j)),'.fasta');
        else
            outputfilename = strcat(Dataset_root,'/',Datasets{1,i},'/WholeRange.fasta');
        end
        
        %create file
        List2RegRegionsv2(SiteList,Ranges(j),Ranges(j),GenomeFile,outputfilename);
   end
end

%(2) - Graded list
GenomeFile = '/Users/phillipseitzer/Documents/MotifCatcher_Methods/Yeast/RawData/S288c/S288c_whole_genome.fasta';
Dataset_root = '/Users/phillipseitzer/Documents/MotifCatcher_Methods/Yeast/Datasets/GradedLists';

for i = 5:5:length(ChIPSeqRegions(:,1))
    
    %create outputfilename
    outputfilename = strcat(Dataset_root,'/Top',num2str(i),'Sites.fasta');

    %create file
    List2RegRegionsv2(SiteListAll(1:i,:),1e10,1e10,GenomeFile,outputfilename);
    
end

%% (4) Comparison to POLII sites
%updated re-analysis 11-2-2011
%segment the set into groups.

%import data. Note that at this CESP threshold, no overlap between
%messy motif (Group 1) and polyA motif (Group2)

%load data
load /Users/phillipseitzer/Documents/MotifCatcher_Methods/Yeast/MotifCatcher/Segmentation/WholeSet/CESP1.00/DataSetProfile.mat

%import sequence
[header sequence] = fastaread(DataSetProfile.SeqFile);

for i = 4:161
   
   %check for group 1 
   if ~isempty(DataSetProfile.MotifMap{i,2})
       
        %find motif in the whole group
        for j = 1:length(header)
           if strmatch(DataSetProfile.MotifMap{i,1},header{1,j},'exact')
                fastawrite('/Users/phillipseitzer/Documents/MotifCatcher_Methods/Yeast/Datasets/Segmentation2/MessyMotif.fasta',header{1,j},sequence{1,j});
           end
        end
       
   elseif ~isempty(DataSetProfile.MotifMap{i,3})
       
        %find motif in the whole group
        for j = 1:length(header)
           if strmatch(DataSetProfile.MotifMap{i,1},header{1,j},'exact')
                fastawrite('/Users/phillipseitzer/Documents/MotifCatcher_Methods/Yeast/Datasets/Segmentation2/polyA.fasta',header{1,j},sequence{1,j});
           end
        end
            
   else
       
       %find motif in the whole group
       for j = 1:length(header)
           if strmatch(DataSetProfile.MotifMap{i,1},header{1,j},'exact')
                fastawrite('/Users/phillipseitzer/Documents/MotifCatcher_Methods/Yeast/Datasets/Segmentation2/NeitherGroup.fasta',header{1,j},sequence{1,j});
           end
        end
   end
end

%import the PolII sites
load MotifCatcher_Methods_Analyses/PolIITop100.mat

%whole set
Counter = 0;
for i = 1:length(PolIITop100(:,1))
    for j = 1:length(header)
        if strfind(header{1,j},PolIITop100{i,1})
            PolIITop100{i,2} = 'yes';
            Counter = Counter + 1;
        end
    end
end

%49 PolII matches

%messy motif
[header3 sequence3] = fastaread('/Users/phillipseitzer/Documents/MotifCatcher_Methods/Yeast/Datasets/Segmentation2/MessyMotif.fasta');

Counter = 0;
for i = 1:length(PolIITop100(:,1))
    for j = 1:length(header3)
        if strfind(header3{1,j},PolIITop100{i,1})
            PolIITop100{i,3} = 'yes';
            Counter = Counter + 1;
        end
    end
end
%35 PolII matches

%polyA motif
[header4 sequence4] = fastaread('/Users/phillipseitzer/Documents/MotifCatcher_Methods/Yeast/Datasets/Segmentation2/polyA.fasta');

Counter = 0;
for i = 1:length(PolIITop100(:,1))
    for j = 1:length(header4)
        if strfind(header4{1,j},PolIITop100{i,1})
            PolIITop100{i,4} = 'yes';
            Counter = Counter + 1;
        end
    end
end
%1 PolII match

%non-polyA-motif - match to 106:
[header5 sequence5] = fastaread('/Users/phillipseitzer/Documents/MotifCatcher_Methods/Yeast/Datasets/Segmentation2/NeitherGroup.fasta');

Counter = 0;
for i = 1:length(PolIITop100(:,1))
    for j = 1:length(header5)
        if strfind(header5{1,j},PolIITop100{i,1})
            PolIITop100{i,5} = 'yes';
            Counter = Counter + 1;
        end
    end
end
%11 PolII matches

%RESULTS!!
%(1) 49/100 top PolII binding sites in the Cse4p whole group set.
%   35/49 (71%) -> MessyMotif
%   1/49 (2%)   -> polyA
%   11/49 (23%) -> Neither Group
%
%(2) What % of sites in each group bind PolII?
%   36/66 (53%) -> MessyMotif
%   1/47 (2%)   -> polyA with CEN
%   1/31 (3%)   -> polyA without CEN
%   11/45 (35%) -> Neither Group


%% MEME analyses
%(1) - All, CEN, and New

%This script runs a MEME ZOOPS on every dataset, and saves to appropriate
%directories.
%MEME_root = '/Users/phillipseitzer/Documents/MotifCatcher_Methods/Yeast/MEME';
%MEME_root = 'Users/phillipseitzer/Documents/MotifCatcher_Methods/Yeast/MEME/min_8_max_10';
%MEME_root = '/Users/phillipseitzer/Documents/MotifCatcher_Methods/Yeast/MEME/min_112_max_120';
%MEME_root = '/Users/phillipseitzer/Documents/MotifCatcher_Methods/Yeast/MEME/min_86_max_94';

MEME_root = '/Users/phillipseitzer/Documents/MotifCatcher_Methods/Yeast/MEME/length_125';

Dataset_root = '/Users/phillipseitzer/Documents/MotifCatcher_Methods/Yeast/Datasets';

extensions = {'CEN','New','All'};
%studies = {'Range50','Range100','Range500','WholeRange'};
studies = {'WholeRange'};

ProgramLocations = struct();
ProgramLocations.MEME = '/Users/phillipseitzer/meme_toplevel/meme/bin/meme.bin';

bfile = '/Users/phillipseitzer/Documents/MotifCatcher_Methods/Yeast/MEME/bfile.model';
DataFile = '/Users/phillipseitzer/Documents/MotifCatcher_Methods/Yeast/Other/6_CEN_for_MEME.fasta';
outputdir = '/Users/phillipseitzer/Documents/MotifCatcher_Methods/Yeast/Other/6_CEN_for_MEME';

%run each MEME ZOOPS run
for i = 1:length(extensions)
   for j = 1:length(studies)
       
        %define data file, and outputdir
        DataFile = strcat(Dataset_root,'/',extensions{1,i},'/',studies{1,j},'.fasta');
        outputdir = strcat(MEME_root,'/',extensions{1,i},'/',studies{1,j});
       
        %build MEME cmd
        cmd = [ProgramLocations.MEME ' ' DataFile ' -minw 125 -maxw 125 -dna -bfile ' bfile ' -mod zoops -oc ' outputdir ' -revcomp -maxsize 1000000'];

        %send to command line
        system(cmd)
        
        disp(['Job ' num2str(i) ' subset ' num2str(j) ' completed.']);
   end
end

%(2) - Graded list

MEME_root = '/Users/phillipseitzer/Documents/MotifCatcher_Methods/Yeast/MEME/GradedLists';
Dataset_root = '/Users/phillipseitzer/Documents/MotifCatcher_Methods/Yeast/Datasets/GradedLists';

ProgramLocations = struct();
ProgramLocations.MEME = '/Users/phillipseitzer/meme_toplevel/meme/bin/meme.bin';
ProgramLocations.FastaGetMarkov = '/Users/phillipseitzer/meme_toplevel/meme/bin/fasta-get-markov';

bfile = '/Users/phillipseitzer/Documents/MotifCatcher_Methods/Yeast/MEME/bfile.model';

for i = 5:5:160
        
    %define data file, and outputdir
    DataFile = strcat(Dataset_root,'/Top',num2str(i),'Sites.fasta');
    outputdir = strcat(MEME_root,'/Top',num2str(i),'Sites');
    
%     [header sequence] = fastaread(DataFile);
%     
%     %create directory
%     system(['mkdir ' MEME_root '/Top' num2str(i) 'Sites']);
%     
%     %create bfile
%     TotalCharacters = 0;
%     for k = 1:length(sequence)
%         TotalCharacters = TotalCharacters + length(sequence{1,k});
%     end
% 
%     %determine order of background file based on the total size of all input
%     %sequences.
%     if TotalCharacters >= 2560
%         order = ' 3 ';
%     elseif TotalCharacters > 1000
%         order = ' 2 ';
%     elseif TotalCharacters > 500
%         order = ' 1 ';
%     else
%         order = ' 0 ';
%     end
% 
%     %Create background file for meme analysis
%     bfile = strcat(MEME_root,'/Top',num2str(i),'Sites/bfile.model');
%     cmd = strcat(ProgramLocations.FastaGetMarkov,' -m ', order, ' < ', DataFile, ' > ',bfile);
%     system(cmd);
%     
    %build MEME cmd
    cmd = [ProgramLocations.MEME ' ' DataFile ' -minw 125 -maxw 125 -dna -bfile ' bfile ' -mod zoops -oc ' outputdir ' -revcomp -maxsize 100000000'];

    %send to command line
    system(cmd)
end

% Functional Test Work: Top 100 Sites, MotifCatcher analysis

%first, load the data set profile.
load /Users/phillipseitzer/Documents/MotifCatcher_Methods/Yeast/MotifCatcher/GradedLists/Top100Sites/CESP1.00/DataSetProfile.mat

% Determine the members of the two families, and the union and
% intersection.
F2 = DataSetProfile.AllMotifsAndLocations{1,2}(3:36,1);
F3 = DataSetProfile.AllMotifsAndLocations{1,3}(3:30,1);
Both = union(F2,F3);
Int = intersect(F2,F3);

%compile into a single structure.
AllSets = cell(1,4);
AllSets{1,1} = F2;
AllSets{1,2} = F3;
AllSets{1,3} = Both;
AllSets{1,4} = Int;

%reformat appropriately.
for i = 1:length(AllSets)
   for j = 1:length(AllSets{1,i}) 
        key = strtok(AllSets{1,i}{j,1},'[');
        AllSets{1,i}{j,1} = key(1:length(key)-1);
   end
end

%initialize output file names.
OutputFileNames = {'F2.txt','F3.txt','Both.txt','Intersection.txt'};

%create output files.
for i = 1:length(AllSets)
   fid = fopen(strcat('YeastTags/',OutputFileNames{1,i}),'w');
   
   for j = 1:length(AllSets{1,i})
       
   %identify key
   key = AllSets{1,i}{j,1};
    
       %look for key in peakslist
       for k= 1:length(ChIPSeqRegions(:,5))
          if strmatch(key,ChIPSeqRegions{k,5},'exact')
              if isempty(strfind(key,'CEN'))

                 modkey = strcat('Y',fliplr(strtok(fliplr(key),'Y')));
                 fprintf(fid,'%s\n',modkey);
                 %disp(['Y' fliplr(strtok(fliplr(key),'Y'))])
              end
          end
       end
   
   end
   fclose(fid);
end

%non-CEN genes sent along, to try to determine any functional relationships
%among these determined gene sets.

load('/Users/phillipseitzer/Documents/MotifCatcher_Methods/Yeast/MotifCatcher/AllSites_125bp_MAST10/CESP0.80/DataSetProfile.mat')

%a modified version of the F2-motif, taken from the whole data set, using a
%MAST-search profile of 10.  Again, all CEN genes are excluded.
fid = fopen('YeastTags/Mod_F2_v2.txt','w');

for i = 4:length(DataSetProfile.MotifMap(:,1))
    if ~isempty(DataSetProfile.MotifMap{i,4})
      if isempty(strfind(DataSetProfile.MotifMap{i,1},'CEN'))

         %find range surrounding locus tag, and extract.
         Hyphens = strfind(DataSetProfile.MotifMap{i,1},'-');
         disp(DataSetProfile.MotifMap{i,1}(Hyphens(1)+1:Hyphens(2)-1))
         fprintf(fid,'%s\n',DataSetProfile.MotifMap{i,1}(Hyphens(1)+1:Hyphens(2)-1));
      end
    end
end

fclose(fid);

%Draw 34 sites at random from the whole set.
[header sequence] = fastaread('/Users/phillipseitzer/Documents/MotifCatcher_Methods/Yeast/Datasets/All/WholeRange.fasta');

for i = 1:10
    
X = randperm(length(header));

fid = fopen(strcat('YeastTags/RandomSets/Rand34_num',num2str(i),'.txt'),'w');

%initializations
Counter = 0;
nonCENCounter = 0;
EnoughnonCEN = false;

while EnoughnonCEN == false
    
    %check next entry
    Counter = Counter + 1;
    
    %ensure no CEN
    if isempty(strfind(header{1,X(Counter)},'CEN'))
        
        %increment non-cen counter
        nonCENCounter = nonCENCounter + 1;
        
        %find locus tag part
        Hyphens = strfind(header{1,X(Counter)},'-');
        
        disp(header{1,X(Counter)}(Hyphens(1)+1:Hyphens(2)-1))
        fprintf(fid,'%s\n',header{1,X(Counter)}(Hyphens(1)+1:Hyphens(2)-1));
        
        if nonCENCounter == 34
           EnoughnonCEN = true; 
        end
    end
end
fclose(fid);

end


% Reanalyze group 1
load /Users/phillipseitzer/Documents/MotifCatcher_Methods/Yeast/MotifCatcher/AllSites_125bp_MAST5/CESP1.00/DataSetProfile.mat;

[header sequence] = fastaread(DataSetProfile.SeqFile);


for i = 4:length(DataSetProfile.MotifMap(:,1))
    if isempty(DataSetProfile.MotifMap{i,2})
        for j = 1:length(header)
           if strmatch(DataSetProfile.MotifMap{i,1},header{1,j},'exact')
                fastawrite('/Users/phillipseitzer/Documents/MotifCatcher_Methods/Yeast/Datasets/Group2.fasta',header{1,j},sequence{1,j});
           end
        end
    else
        for j = 1:length(header)
           if strmatch(DataSetProfile.MotifMap{i,1},header{1,j},'exact')
                fastawrite('/Users/phillipseitzer/Documents/MotifCatcher_Methods/Yeast/Datasets/Group1.fasta',header{1,j},sequence{1,j})
           end
        end
    end
end

%Next: MotifCatcher run on Group 2, look for 15 nt to 30 nt (protein
%binding sites)

